@@ -39,3 +39,6 @@ from .cf import CF
 from .vaecf import VAECF
 from .ctr import CTR
 from .hft import HFT
+from .ncf import GMF
+from .ncf import MLP
+from .ncf import NeuMF
\ No newline at end of file
